import { CommitmentStatus, IOwnershipCommitment } from '@energyweb/origin-backend-core';
import { ContractTransaction } from 'ethers';
import { BigNumber } from 'ethers/utils';
import { Configuration, Timestamp } from '@energyweb/utils-general';
import { PreciseProofEntity } from './PreciseProofEntity';
export interface ICertificateEnergy {
    publicVolume: BigNumber;
    privateVolume: BigNumber;
    claimedVolume: BigNumber;
}
export interface ICertificate {
    id: number;
    issuer: string;
    deviceId: string;
    energy: ICertificateEnergy;
    generationStartTime: number;
    generationEndTime: number;
    certificationRequestId: number;
    creationTime: number;
    creationBlockHash: string;
}
export declare class Certificate extends PreciseProofEntity implements ICertificate {
    deviceId: string;
    energy: ICertificateEnergy;
    generationStartTime: number;
    generationEndTime: number;
    issuer: string;
    creationTime: number;
    creationBlockHash: string;
    ownershipCommitment: IOwnershipCommitment;
    certificationRequestId: number;
    initialized: boolean;
    data: string;
    private privateOwnershipCommitment;
    constructor(id: number, configuration: Configuration.Entity);
    static create(to: string, value: BigNumber, fromTime: Timestamp, toTime: Timestamp, deviceId: string, configuration: Configuration.Entity, isVolumePrivate?: boolean): Promise<Certificate>;
    sync(): Promise<Certificate>;
    get isOwned(): boolean;
    get isClaimed(): boolean;
    claim(amount?: BigNumber): Promise<ContractTransaction>;
    requestMigrateToPublic(): Promise<ContractTransaction>;
    migrateToPublic(): Promise<ContractTransaction>;
    transfer(to: string, amount?: BigNumber, privately?: boolean): Promise<ContractTransaction | CommitmentStatus>;
    approvePrivateTransfer(): Promise<ContractTransaction>;
    revoke(): Promise<ContractTransaction>;
    isRevoked(): Promise<boolean>;
}
